@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -141,7 +141,7 @@ typedef struct { int minmax ;
 
 
 static char sccsid[] UNUSED = "@(#)mpsio.c	4.4	11/06/04" ;
-static char svnid[] UNUSED = "$Id: mpsio.c 239 2008-06-05 01:12:14Z lou $" ;
+static char svnid[] UNUSED = "$Id: mpsio.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 /*
   A bunch of definitions and declarations for mpsin and its slave routines.
@@ -306,7 +306,7 @@ static mpsinstate_enum mpsin_name (ioid mpschn, consys_struct **consys,
   tok = strtok(NULL,sepchars) ;
 # if 0
   if (tok == NULL || cistrcmp(tok,"free") != 0)
-    warn(150,rtnnme,"free",(tok == NULL)?"":tok) ;
+    dywarn(150,rtnnme,"free",(tok == NULL)?"":tok) ;
 # endif
 /*
   Now check for the "rows" keyword that marks the start of the rows section.
@@ -359,6 +359,11 @@ static mpsinstate_enum mpsin_rows (ioid mpschn, consys_struct *consys)
   bool seen_cols,keep_row ;
   pkvec_struct *pkrow ;
 
+  /*
+    Useful to suppress compiler warnings re. integer <-> pointer conversion
+  */
+  ptrdiff_t intermediary ;
+
   const char *rtnnme = "mpsin_rows",
 	     *mysection = "rows" ;
 
@@ -409,7 +414,7 @@ static mpsinstate_enum mpsin_rows (ioid mpschn, consys_struct *consys)
       { typecode = contypNB ;
 	if (!(consys->objndx <= 0 &&
 	      (consys->objnme == NULL || strcmp(tok,consys->objnme) == 0)))
-	{ warn(172,rtnnme,consys->nme,tok) ;
+	{ dywarn(172,rtnnme,consys->nme,tok) ;
 	  keep_row = FALSE ; }
 	break ; }
       case 'E':
@@ -447,8 +452,10 @@ static mpsinstate_enum mpsin_rows (ioid mpschn, consys_struct *consys)
 	if (consys->objnme == NULL) consys->objnme = STRALLOC(pkrow->nme) ; } }
     else
     { pkrow->ndx = -1 ; }
-    if ((void *) pkrow->ndx !=
-	enter(STRALLOC(pkrow->nme),conhash,conhashsze,(void *) pkrow->ndx))
+    intermediary = pkrow->ndx ;
+    if ((void *) intermediary !=
+	dyhash_enter(STRALLOC(pkrow->nme),conhash,conhashsze,
+		     (void *) intermediary))
     { errmsg(155,rtnnme,"constraint",
 	     consys_nme(consys,'c',pkrow->ndx,TRUE,NULL)) ;
       return (mpsinINV) ; }
@@ -456,7 +463,7 @@ static mpsinstate_enum mpsin_rows (ioid mpschn, consys_struct *consys)
   Check for garbage at the end of the line, and complain if there is any.
 */
     tok = strtok(NULL,sepchars) ;
-    if (tok != NULL) warn(157,rtnnme,tok,"constraint",pkrow->nme) ; }
+    if (tok != NULL) dywarn(157,rtnnme,tok,"constraint",pkrow->nme) ; }
 /*
   This is the end of the loop which parses the rows section.  Check that we
   got here because we saw the "columns" indicator, and fail if things are
@@ -519,6 +526,11 @@ static mpsinstate_enum mpsin_columns (ioid mpschn, consys_struct *consys)
   char *rownam,*tok,*chkptr ;
   char colnam[50] ;		/* grossly oversized, but safe */
 
+  /*
+    Useful to suppress compiler warnings re. integer <-> pointer conversion
+  */
+  ptrdiff_t intermediary ;
+
   const char *rtnnme = "mpsin_columns",
 	     *mysection = "columns" ;
 
@@ -580,8 +592,10 @@ static mpsinstate_enum mpsin_columns (ioid mpschn, consys_struct *consys)
       { if (consys_addcol_pk(consys,vartype,pkcol,0.0,0.0,0.0) == FALSE)
 	{ errmsg(156,rtnnme,"column",consys->nme,pkcol->nme) ;
 	  return (mpsinINV) ; }
-	if ((void *) pkcol->ndx !=
-	    enter(STRALLOC(pkcol->nme),varhash,varhashsze,(void *) pkcol->ndx))
+	intermediary = pkcol->ndx ;
+	if ((void *) intermediary !=
+	    dyhash_enter(STRALLOC(pkcol->nme),varhash,varhashsze,
+	    	  (void *) intermediary))
 	{ errmsg(155,rtnnme,"variable",
 		 consys_nme(consys,'v',pkcol->ndx,TRUE,NULL)) ;
 	  return (mpsinINV) ; }
@@ -632,7 +646,9 @@ static mpsinstate_enum mpsin_columns (ioid mpschn, consys_struct *consys)
 	{ if (sosset == TRUE)
 	  { errmsg(161,rtnnme,"sosorg",pkcol->nme,"sosend") ;
 	    return (mpsinINV) ; }
-	  sosndx = (int) lookup(pkcol->nme,conhash,conhashsze) ;
+	  intermediary =
+		(ptrdiff_t) dyhash_lookup(pkcol->nme,conhash,conhashsze) ;
+	  sosndx = (int) intermediary ;
 	  if (sosndx == 0)
 	  { errmsg(162,rtnnme,"SOS constraint",pkcol->nme,"marker","sosorg") ;
 	    return (mpsinINV) ; }
@@ -644,7 +660,8 @@ static mpsinstate_enum mpsin_columns (ioid mpschn, consys_struct *consys)
 	  sos3 = (lnk_struct *) MALLOC(sizeof(lnk_struct)) ;
 	  sos3->llnxt = sos3lst ;
 	  sos3lst = sos3 ;
-	  lnk_in(sos3,sosndx) ; }
+	  intermediary = sosndx ;
+	  lnk_in(sos3,intermediary) ; }
 	else
 	if (cistrcmp(tok,"'sosend'") == 0)
 	{ if (sosset != TRUE)
@@ -705,7 +722,8 @@ static mpsinstate_enum mpsin_columns (ioid mpschn, consys_struct *consys)
       if (chkptr == tok || errno == ERANGE)
       { errmsg(165,rtnnme,tok,consys->nme,pkcol->nme,rownam) ;
 	return (mpsinINV) ; }
-      rowndx = (int) lookup(rownam,conhash,conhashsze) ;
+      intermediary = (ptrdiff_t) dyhash_lookup(rownam,conhash,conhashsze) ;
+      rowndx = (int) intermediary ;
       if (rowndx == 0)
       { errmsg(166,rtnnme,"constraint",rownam,"column",consys->nme,pkcol->nme) ;
 	return (mpsinINV) ; }
@@ -771,6 +789,10 @@ static mpsinstate_enum mpsin_rhs (ioid mpschn, consys_struct *consys)
   lex_struct *lex ;
   char *tok,*rownme,*chkptr ;
   const char *rhsnme ;
+  /*
+    Useful to suppress compiler warnings re. integer <-> pointer conversion
+  */
+  ptrdiff_t intermediary ;
 
   const char *rtnnme = "mpsin_rhs",
 	     *mysection = "rhs" ;
@@ -834,7 +856,8 @@ static mpsinstate_enum mpsin_rhs (ioid mpschn, consys_struct *consys)
   install the coefficient in the rhs vector.
 */
     for ( ; tok != NULL ; tok = strtok(NULL,sepchars))
-    { rowndx = (int) lookup(tok,conhash,conhashsze) ;
+    { intermediary = (ptrdiff_t) dyhash_lookup(tok,conhash,conhashsze) ;
+      rowndx = (int) intermediary ;
       if (rowndx == 0)
       { errmsg(166,rtnnme,"constraint",tok,consys_assocnme(NULL,CONSYS_RHS),
 	       consys->nme,rhsnme) ;
@@ -907,6 +930,10 @@ static mpsinstate_enum mpsin_ranges (ioid mpschn, consys_struct *consys)
   lex_struct *lex ;
   const char *rngnme ;
   char *rownme,*tok,*chkptr ;
+  /*
+    Useful to suppress compiler warnings re. integer <-> pointer conversion
+  */
+  ptrdiff_t intermediary ;
 
   const char *rtnnme = "mpsin_ranges",
 	     *mysection = "ranges" ;
@@ -977,7 +1004,8 @@ static mpsinstate_enum mpsin_ranges (ioid mpschn, consys_struct *consys)
   to get the row index, then try for the coefficient.
 */
     for ( ; tok != NULL ; tok = strtok(NULL,sepchars))
-    { rowndx = (int) lookup(tok,conhash,conhashsze) ;
+    { intermediary = (ptrdiff_t) dyhash_lookup(tok,conhash,conhashsze) ;
+      rowndx = (int) intermediary ;
       if (rowndx == 0)
       { errmsg(166,rtnnme,"constraint",tok,"range vector",consys->nme,rngnme) ;
 	return (mpsinINV) ; }
@@ -1085,6 +1113,10 @@ static mpsinstate_enum mpsin_bounds (ioid mpschn, consys_struct *consys)
   lex_struct *lex ;
   const char *bndnme ;
   char *varnme,*bndcode,*tok,*chkptr ;
+  /*
+    Useful to suppress compiler warnings re. integer <-> pointer conversion
+  */
+  ptrdiff_t intermediary ;
 
   const char *rtnnme = "mpsin_bounds",
 	     *mysection = "bounds" ;
@@ -1163,7 +1195,8 @@ static mpsinstate_enum mpsin_bounds (ioid mpschn, consys_struct *consys)
     if (varnme == NULL)
     { errmsg(153,rtnnme,"variable",mysection) ;
       return (mpsinINV) ; }
-    colndx = (int) lookup(varnme,varhash,varhashsze) ;
+    intermediary = (ptrdiff_t) dyhash_lookup(varnme,varhash,varhashsze) ;
+    colndx = (int) intermediary ;
     if (colndx == 0)
     { errmsg(162,rtnnme,"variable",varnme,consys->nme,mysection) ;
       return (mpsinINV) ; }
@@ -1288,6 +1321,10 @@ static mpsinstate_enum mpsin_enddata (ioid mpschn, consys_struct *consys,
   pkvec_struct *pkvec ;
   hel *entry ;
   lex_struct *lex ;
+  /*
+    Useful to suppress compiler warnings re. integer <-> pointer conversion
+  */
+  ptrdiff_t intermediary ;
 
   const char *rtnnme = "mpsin_enddata" ;
 
@@ -1379,7 +1416,8 @@ static mpsinstate_enum mpsin_enddata (ioid mpschn, consys_struct *consys,
   Do some integrity checks while we're at it, provided debugging is enabled.
 */
   for (sos3 = sos3lst ; sos3 != NULL ; sos3 = sos3->llnxt)
-  { ndx = lnk_out(sos3,int) ;
+  { intermediary = lnk_out(sos3,ptrdiff_t) ;
+    ndx = (int) intermediary ;
 #   ifndef NDEBUG
     if (ndx < 1 || ndx > consys->archccnt)
     { errmsg(102,rtnnme,consys->nme,"constraint",ndx,1,consys->archccnt) ;
@@ -1407,7 +1445,7 @@ static mpsinstate_enum mpsin_enddata (ioid mpschn, consys_struct *consys,
 */
   for (ndx = consys->archccnt ; ndx > 0 ; ndx--)
   { if (consys_infnormrow(consys,ndx) == 0)
-    { warn(179,rtnnme,consys->nme,consys_nme(consys,'c',ndx,FALSE,NULL),ndx) ;
+    { dywarn(179,rtnnme,consys->nme,consys_nme(consys,'c',ndx,FALSE,NULL),ndx) ;
       if (consys_delrow(consys,ndx) == FALSE)
       { errmsg(112,rtnnme,consys->nme,"delete","row",
 	       consys_nme(consys,'c',ndx,FALSE,NULL),ndx) ;
