@@ -9,7 +9,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -79,7 +79,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)osi_dylp.c	1.10	09/25/04" ;
-static char svnid[] UNUSED = "$Id: osi_dylp.c 305 2009-10-16 23:27:55Z lou $" ;
+static char svnid[] UNUSED = "$Id: osi_dylp.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 const char *osidylp_version = "1.10" ;			/* sccs! */
 const char *osidylp_time ;
@@ -102,16 +102,13 @@ const char *osidylp_time ;
 
   ttyout		i/o id for output to the user's terminal
   ttyin			i/o id for input from the user's terminal
-  dy_cmdchn		i/o id for input from the command file
-  dy_logchn		i/o id for the execution log file
 
-  dy_cmdecho		controls echoing of command input to stdout
+  dy_logchn		i/o id for the execution log file (set via
+  			dy_setlogchn)
   dy_gtxecho		controls echoing of generated text to stdout
+  			(set via dy_setgtxecho)
 */
 
-ioid dy_cmdchn,dy_logchn ;
-bool dy_cmdecho, dy_gtxecho ;
-
 /*
   File paths used elsewhere in osi_dylp.
 
@@ -147,9 +144,9 @@ static void print_version (ioid chn, bool echo,
   const char *disc2 = "warranty; not even for MERCHANTABILITY or FITNESS FOR A"
 		      " PARTICULAR PURPOSE." ;
 
-  dyio_outfmt(dy_logchn,dy_gtxecho,"\n%s (%s) V %s",cmd,nme,ver) ;
-  dyio_outfmt(dy_logchn,dy_gtxecho,"\nCopyright (C) 2004 Lou Hafer") ;
-  dyio_outfmt(dy_logchn,dy_gtxecho,"\n%s\n%s\n",disc1,disc2) ;
+  dyio_outfmt(chn,echo,"\n%s (%s) V %s",cmd,nme,ver) ;
+  dyio_outfmt(chn,echo,"\nCopyright (C) 2004 Lou Hafer") ;
+  dyio_outfmt(chn,echo,"\n%s\n%s\n",disc1,disc2) ;
 
   return ; }
 
@@ -397,13 +394,13 @@ static void stats_lp (const char *outpath, bool echo, lpprob_struct *lp,
   Set up the output. Don't echo this to stdout twice.
 */
   if (outpath == NULL)
-  { warn(2,rtnnme,"file name") ;
+  { dywarn(2,rtnnme,"file name") ;
     chn = IOID_NOSTRM ; }
   else
   { chn = dyio_pathtoid(outpath,NULL) ;
     if (chn == IOID_INV) chn = dyio_openfile(outpath,"w") ;
     if (chn == IOID_INV)
-    { warn(10,rtnnme,outpath,"w") ;
+    { dywarn(10,rtnnme,outpath,"w") ;
       chn = IOID_NOSTRM ; }
     if (strcmp(outpath,"stdout") == 0) echo = FALSE ; }
 /*
@@ -469,13 +466,9 @@ static lpret_enum do_lp (struct timeval *elapsed, int printlvl)
 	   not really dylp's fault.
 */
 
-{ int ndx,i,flips ;
-  bool *flipped ;
-
-  lpret_enum lpret ;
+{ lpret_enum lpret ;
   lpopts_struct *initial_lpopts ;
   lpstats_struct *initial_lpstats ;
-  basis_struct *basis ;
 
   struct timeval diff,before,after ;
 
@@ -537,9 +530,9 @@ int main (int argc, char *argv[])
 { time_t timeval ;
   struct tm *tm ;
   char runtime[50] ;
-  ioid ttyin,ttyout,outchn ;
+  ioid ttyin,ttyout,outchn,logchn,cmdchn ;
   int optlett,printlvl ;
-  bool silent,terse,swaperrs,errecho,doversion,dohelp ;
+  bool silent,terse,swaperrs,errecho,gtxecho,doversion,dohelp ;
   const char *errmsgpath,*errlogpath,*optpath,*mpspath,*logpath ;
 
   struct timeval lptime ;
@@ -581,13 +574,12 @@ int main (int argc, char *argv[])
 
   ttyout = IOID_INV ;
   ttyin = IOID_INV ;
-  dy_logchn = IOID_INV ;
+  logchn = IOID_INV ;
   outchn = IOID_INV ;
 
   silent = FALSE ;
   terse = FALSE ;
-  dy_gtxecho = TRUE ;
-  dy_cmdecho = FALSE ;
+  gtxecho = TRUE ;
   doversion = FALSE ;
   dohelp = FALSE ;
 
@@ -618,11 +610,11 @@ int main (int argc, char *argv[])
 	break ; }
       case 's':
       { silent = TRUE ;
-	dy_gtxecho = FALSE ;
+	gtxecho = FALSE ;
 	break ; }
       case 't':
       { terse = TRUE ;
-	dy_gtxecho = FALSE ;
+	gtxecho = FALSE ;
 	break ; }
       case 'p':
       { printlvl = atoi(optarg) ;
@@ -668,7 +660,7 @@ int main (int argc, char *argv[])
   Grab the time and format it nicely.
 */
   if (time(&timeval) == (time_t)(-1))
-  { warn(19,rtnnme) ;
+  { dywarn(19,rtnnme) ;
     osidylp_time = "n/a" ; }
   else
   { tm = localtime(&timeval) ;
@@ -679,8 +671,8 @@ int main (int argc, char *argv[])
     { osidylp_time = "n/a" ; } }
 /*
   Figure out the appropriate settings for silent and terse.
-  silent is set to (silent || terse), and is passed to process_cmds so that
-	 it can properly handle dy_cmdecho and dy_gtxecho.
+  silent is set to (silent || terse), and is passed to dy_processcmds so that
+	 it can properly handle command and generated text echo.
   terse	 is set for ease of controlling the output specifically mentioned in
 	 conjunction with terse mode (which is controlled from this routine).
 	 The proper value is (terse || !silent).
@@ -719,17 +711,19 @@ int main (int argc, char *argv[])
   { errmsg(1,rtnnme,__LINE__) ;
     exit(4) ; }
   (void) dyio_setmode(ttyin,'l') ;
-  dy_cmdchn = ttyin ;
+  cmdchn = ttyin ;
 /*
   Initialize logging.
 */
   if (logpath != NULL)
-  { dy_logchn = dyio_openfile(logpath,"w") ;
-    if (dy_logchn == IOID_INV)
-    { warn(201,rtnnme,logpath) ;
-      dy_logchn = IOID_NOSTRM ; } }
+  { logchn = dyio_openfile(logpath,"w") ;
+    if (logchn == IOID_INV)
+    { dywarn(201,rtnnme,logpath) ;
+      logchn = IOID_NOSTRM ; } }
   else
-  { dy_logchn = IOID_NOSTRM ; }
+  { logchn = IOID_NOSTRM ; }
+  dy_setlogchn(logchn) ;
+  dy_setgtxecho(gtxecho) ;
 /*
   Are we supposed to merge the error messages with the log stream? (Note that
   errors will be echoed to stderr unless we're running silent. If the user's
@@ -737,32 +731,32 @@ int main (int argc, char *argv[])
   code that it should reset the error logging channel if it ever resets the
   main logging channel.
 */
-  if (errlogpath == NULL && dy_logchn != IOID_NOSTRM)
+  if (errlogpath == NULL && logchn != IOID_NOSTRM)
   { swaperrs = TRUE ;
     errlogpath = logpath ;
     if (dyio_chgerrlog(errlogpath,errecho) == FALSE)
-    { warn(18,rtnnme,"<null>",errlogpath) ; } }
+    { dywarn(18,rtnnme,"<null>",errlogpath) ; } }
 /*
   Ok, after all that work, check if we've been asked for the version or usage
   messages. If so, do it and head for the exit. Version preempts help.
 */
   if (doversion == TRUE)
-  { print_version(dy_logchn,dy_gtxecho,argv[0],rtnnme,osidylp_version) ;
+  { print_version(logchn,gtxecho,argv[0],rtnnme,osidylp_version) ;
     goto NOOUTFILE_CLEANUP ; }
   if (dohelp == TRUE)
-  { print_help(dy_logchn,dy_gtxecho,argv[0]) ;
+  { print_help(logchn,gtxecho,argv[0]) ;
     goto NOOUTFILE_CLEANUP ; }
 /*
   We're up! Banners to the appropriate places.
 */
-  dyio_outfmt(dy_logchn,terse,"\n\t\t    %s\tV %s\n",rtnnme,osidylp_version) ;
-  dyio_outfmt(dy_logchn,terse,"\n\t\t%s",runtime) ;
-  dyio_outfmt(dy_logchn,terse,"\n\n") ;
+  dyio_outfmt(logchn,terse,"\n\t\t    %s\tV %s\n",rtnnme,osidylp_version) ;
+  dyio_outfmt(logchn,terse,"\n\t\t%s",runtime) ;
+  dyio_outfmt(logchn,terse,"\n\n") ;
   if (outpath != NULL && strcmp(outpath,"stdout") != 0)
   { outchn = dyio_pathtoid(outpath,NULL) ;
     if (outchn == IOID_INV) outchn = dyio_openfile(outpath,"w") ;
     if (outchn == IOID_INV)
-    { warn(10,rtnnme,outpath,"w") ; }
+    { dywarn(10,rtnnme,outpath,"w") ; }
     else
     { dyio_outfmt(outchn,FALSE,"\n\t\t    %s\tV %s\n",rtnnme,osidylp_version) ;
       dyio_outfmt(outchn,FALSE,"\n\t\t%s",runtime) ;
@@ -786,10 +780,10 @@ int main (int argc, char *argv[])
   optpath = NULL ;
 # endif
   if (optpath != NULL)
-  { dy_cmdchn = dyio_openfile(optpath,"r") ;
-    if (dy_cmdchn == IOID_INV) exit (1) ;
-    (void) dyio_setmode(dy_cmdchn,'l') ;
-    switch (process_cmds(silent))
+  { cmdchn = dyio_openfile(optpath,"r") ;
+    if (cmdchn == IOID_INV) exit (1) ;
+    (void) dyio_setmode(cmdchn,'l') ;
+    switch (dy_processcmds(cmdchn,silent,main_lpopts,main_lptols))
     { case cmdOK:
       { break ; }
       case cmdHALTERROR:
@@ -798,9 +792,9 @@ int main (int argc, char *argv[])
       { exit (0) ; }
       default:
       { exit (1) ; } }
-    if (dy_cmdchn != ttyin)
-    { (void) dyio_closefile(dy_cmdchn) ;
-      dy_cmdchn = IOID_INV ; } }
+    if (cmdchn != ttyin)
+    { (void) dyio_closefile(cmdchn) ;
+      cmdchn = IOID_INV ; } }
 /*
   Make an attempt to read the mps input file.
 */
@@ -833,17 +827,17 @@ int main (int argc, char *argv[])
 */
   if (printlvl >= 1)
   { if (printlvl >= 2)
-    { dy_dumpcompact(dy_logchn,
-		     (dy_logchn == IOID_INV)?TRUE:FALSE,main_lp,FALSE) ; }
-    dyio_outfmt(dy_logchn,TRUE,"\nReturn code %s",dy_prtlpret(main_lp->lpret)) ;
+    { dy_dumpcompact(logchn,
+		     (logchn == IOID_INV)?TRUE:FALSE,main_lp,FALSE) ; }
+    dyio_outfmt(logchn,TRUE,"\nReturn code %s",dy_prtlpret(main_lp->lpret)) ;
     if (main_lp->phase == dyDONE)
-      dyio_outfmt(dy_logchn,TRUE," after %d pivots",main_lp->iters) ;
+      dyio_outfmt(logchn,TRUE," after %d pivots",main_lp->iters) ;
     if (main_lp->lpret == lpOPTIMAL)
-    { dyio_outfmt(dy_logchn,TRUE,"; objective %.8g",main_lp->obj) ; }
-    dyio_outfmt(dy_logchn,TRUE,
+    { dyio_outfmt(logchn,TRUE,"; objective %.8g",main_lp->obj) ; }
+    dyio_outfmt(logchn,TRUE,
 		" (%.2f sec.)",lptime.tv_sec+lptime.tv_usec/1e6) ;
-    dyio_outfmt(dy_logchn,TRUE,".\n") ;
-    dyio_flushio(dy_logchn,dy_gtxecho) ; }
+    dyio_outfmt(logchn,TRUE,".\n") ;
+    dyio_flushio(logchn,gtxecho) ; }
 /*
   Final cleanup. Free space used by the remaining main_* structures.
 */
@@ -867,8 +861,8 @@ int main (int argc, char *argv[])
   subsystem.
 */
   NOOUTFILE_CLEANUP:
-  if (dy_logchn != IOID_INV && dy_logchn != IOID_NOSTRM)
-  { (void) dyio_closefile(dy_logchn) ; }
+  if (logchn != IOID_INV && logchn != IOID_NOSTRM)
+  { (void) dyio_closefile(logchn) ; }
   dyio_ioterm() ;
   errterm() ;
 
