@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -25,7 +25,7 @@
 #include "glpinv.h"
 
 static char sccsid[] UNUSED = "@(#)dy_basis.c	4.6	11/06/04" ;
-static char svnid[] UNUSED = "$Id: dy_basis.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_basis.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 /*
   The basis data structure. glpinv/glpluf does not distinguish between
@@ -584,7 +584,7 @@ static void adjust_basis (int *p_patchcnt, patch_struct **p_patches)
   patch_struct *patches ;
 
 
-#ifdef DYLP_PARANOIA
+#if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
   const char *rtnnme = "adjust_basis" ;
 
   if (dy_sys == NULL)
@@ -818,7 +818,7 @@ static dyret_enum adjust_therest (int patchcnt, patch_struct *patches)
 	{ 
 #	  ifndef DYLP_NDEBUG
 	  if (dy_opts->print.dual >= 1)
-	  { warn(346,rtnnme,
+	  { dywarn(346,rtnnme,
 		 dy_sys->nme,dy_prtlpphase(phase,TRUE),dy_lp->tot.iters+1,
 		 dy_prtvstat(statj),consys_nme(dy_sys,'v',j,FALSE,NULL),j) ; }
 #	  endif
@@ -887,7 +887,7 @@ static dyret_enum adjust_therest (int patchcnt, patch_struct *patches)
 #	ifndef DYLP_NDEBUG
 	cbarj = dy_cbar[j] ;
 	if (dy_opts->print.dual >= 1)
-	{ warn(347,rtnnme,
+	{ dywarn(347,rtnnme,
 	       dy_sys->nme,dy_prtlpphase(phase,TRUE),dy_lp->tot.iters+1,
 	       consys_nme(dy_sys,'v',j,FALSE,NULL),j,
 	       dy_prtvstat(statj),j,cbarj,dy_tols->dfeas) ; }
@@ -899,7 +899,7 @@ static dyret_enum adjust_therest (int patchcnt, patch_struct *patches)
 	{
 #	  ifndef DYLP_NDEBUG
 	  if (dy_opts->print.dual >= 1)
-	  { warn(347,rtnnme,
+	  { dywarn(347,rtnnme,
 		 dy_sys->nme,dy_prtlpphase(phase,TRUE),dy_lp->tot.iters+1,
 		 consys_nme(dy_sys,'v',j,FALSE,NULL),j,
 		 dy_prtvstat(statj),j,cbarj,dy_tols->dfeas) ; }
@@ -915,7 +915,7 @@ static dyret_enum adjust_therest (int patchcnt, patch_struct *patches)
 	{
 #	  ifndef DYLP_NDEBUG
 	  if (dy_opts->print.dual >= 1)
-	  { warn(347,rtnnme,
+	  { dywarn(347,rtnnme,
 		 dy_sys->nme,dy_prtlpphase(phase,TRUE),dy_lp->tot.iters+1,
 		 consys_nme(dy_sys,'v',j,FALSE,NULL),j,
 		 dy_prtvstat(statj),j,cbarj,dy_tols->dfeas) ; }
