@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -24,7 +24,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_coldstart.c	4.6	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_coldstart.c 307 2009-10-16 23:32:20Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_coldstart.c 407 2010-12-31 20:48:48Z lou $" ;
 
 
 
@@ -473,7 +473,7 @@ static bool cold_createdysys (consys_struct *orig_sys, int eqcnt, int ineqcnt)
   { m_sze = orig_sys->concnt ;
     n_sze = orig_sys->archvcnt+m_sze ; }
   else
-  { m_sze = eqcnt+((int) orig_sys->concnt*dy_opts->active.cons) ;
+  { m_sze = eqcnt+((int) (orig_sys->concnt*dy_opts->active.cons)) ;
     n_sze = (int) (orig_sys->archvcnt*dy_opts->active.vars+m_sze) ; }
 # ifndef DYLP_NDEBUG
   if (dy_opts->print.setup >= 1)
