@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 #define DYLP_INTERNAL
@@ -17,7 +17,7 @@
 #include <limits.h>
 
 static char sccsid[] UNUSED = "@(#)dy_conmgmt.c	4.6	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_conmgmt.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_conmgmt.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 /*
   This file contains routines for primal constraint management. It provides
@@ -583,7 +583,7 @@ bool dy_actBLogPrimCon (consys_struct *orig_sys, int origi, int *inactvars)
 	 (dy_lp->lpret == lpSWING || dy_lp->lpret == lpUNBOUNDED)))
     { /* ok */ }
     else
-    { warn(442,rtnnme,
+    { dywarn(442,rtnnme,
 	   dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	   consys_nme(dy_sys,'c',i,FALSE,NULL),i,dy_prtvstat(dy_status[i]),
 	   (dy_opts->con.actlvl == 0)?"violated":"tight or violated") ; } }
