@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -17,13 +17,14 @@
 */
 
 
+#define DYLP_INTERNAL
 
 #include "dylib_errs.h"
 #include "dylib_std.h"
 #include "dy_consys.h"
 
 static char sccsid[] UNUSED = "@(#)dy_consys_mathutils.c	4.5	11/11/04" ;
-static char svnid[] UNUSED = "$Id: dy_consys_mathutils.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_consys_mathutils.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 
 
@@ -765,7 +766,7 @@ bool consys_mulrow (consys_struct *consys, int rowndx, double scalar)
 # endif
 # ifndef DYLP_NDEBUG
   if (scalar == 0 && flgon(consys->opts,CONSYS_WRNZERO))
-  { warn(132,rtnnme,consys->nme,"row",rowhdr->nme,rowndx) ; }
+  { dywarn(132,rtnnme,consys->nme,"row",rowhdr->nme,rowndx) ; }
 # endif
   if (consys->cub != NULL && consys->clb != NULL)
     do_conbnds = TRUE ;
