@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -37,6 +37,7 @@
 */
 
 
+#define DYLP_INTERNAL
 
 #include "dylib_errs.h"
 #include "dylib_std.h"
@@ -50,7 +51,7 @@
 #endif
 
 static char sccsid[] UNUSED = "@(#)dy_consys_scaling.c	4.8	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_consys_scaling.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_consys_scaling.c 436 2011-06-08 21:06:45Z stefan $" ;
 
 
 
@@ -207,7 +208,7 @@ bool consys_geomscale (consys_struct *consys,
   double *rowscale,*colscale ;
   coeff_struct *coeffij ;
 
-# if defined(DYLP_PARANOIA) || CONSYS_SCALING_DEBUG >= 1
+# if defined(DYLP_PARANOIA) || CONSYS_SCALING_DEBUG >= 1 || MALLOC_DEBUG == 2
 
   char *rtnnme = "consys_geomscale" ;
 
@@ -226,6 +227,7 @@ bool consys_geomscale (consys_struct *consys,
   if (p_colscale == NULL)
   { errmsg(2,rtnnme,"&colscale") ;
     return (FALSE) ; }
+
 # endif
 
 /*
@@ -342,7 +344,7 @@ bool consys_equiscale (consys_struct *consys,
   double *rowscale,*colscale ;
   coeff_struct *coeffij ;
 
-# if defined(DYLP_PARANOIA) || CONSYS_SCALING_DEBUG >= 1
+# if defined(DYLP_PARANOIA) || CONSYS_SCALING_DEBUG >= 1 || MALLOC_DEBUG == 2
 
   char *rtnnme = "consys_equiscale" ;
 
@@ -361,6 +363,7 @@ bool consys_equiscale (consys_struct *consys,
   if (p_colscale == NULL)
   { errmsg(2,rtnnme,"&colscale") ;
     return (FALSE) ; }
+
 # endif
 
 /*
