@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -133,7 +133,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_dual.c	4.7	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_dual.c 299 2009-08-28 01:35:28Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_dual.c 407 2010-12-31 20:48:48Z lou $" ;
 
 
 
@@ -353,24 +353,31 @@ static dyret_enum dual2 (void)
   the pivot reject list; this is indicated by a return value of dyrPUNT.
   Optimality falls into the default case. Call dy_dealWithPunt to free up any
   potential candidates on the pivot rejection list and iterate to try again.
+
+  If the problem context is cxLOAD, this is all we need to do. Skip to the end
+  game.
 */
     outresult = dy_dualout(&candxi) ;
-    switch (outresult)
-    { case dyrOK:
-      { do_pivots = TRUE ;
-	break ; }
-      case dyrPUNT:
-      { outresult = dy_dealWithPunt() ;
-	if (outresult == dyrRESELECT)
-	{ continue ; }
-	else
+    if (dy_opts->context == cxLOAD)
+    { do_pivots = FALSE ;
+      lpretval = outresult ; }
+    else
+    { switch (outresult)
+      { case dyrOK:
+	{ do_pivots = TRUE ;
+	  break ; }
+	case dyrPUNT:
+	{ outresult = dy_dealWithPunt() ;
+	  if (outresult == dyrRESELECT)
+	  { continue ; }
+	  else
+	  { do_pivots = FALSE ;
+	    lpretval = outresult ; }
+	  break ; }
+	default:
 	{ do_pivots = FALSE ;
-	  lpretval = outresult ; }
-	break ; }
-      default:
-      { do_pivots = FALSE ;
-	lpretval = outresult ;
-	break ; } }
+	  lpretval = outresult ;
+	  break ; } } }
 #   ifdef DYLP_PARANOIA
     if (candxi <= 0 && outresult == dyrOK)
     { dyio_outfmt(dy_logchn,TRUE,
@@ -670,7 +677,12 @@ static dyret_enum dual2 (void)
 		   dy_prtdyret(tmpretval),dy_prtlpphase(dy_lp->phase,TRUE),
 		   dy_lp->tot.iters) ; } }
 #       endif
-      } } }
+      } }
+/*
+  Regardless of the result, if we're just here to load the problem, escape the
+  loop.
+*/
+    if (dy_opts->context == cxLOAD) break ; }
 /*
   We've finished the outer loop. Clean up before we leave.
 */
