@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 #define DYLP_INTERNAL
@@ -16,7 +16,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_dualmultipivot.c	4.6	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_dualmultipivot.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_dualmultipivot.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 /*
   This is an experimental dual pivoting algorithm. The inspiration comes from
@@ -920,12 +920,12 @@ bool selectWithInf (int i, dualcand_struct *incands,
   # ifdef DYLP_PARANOIA
     if (dy_lp->d2.iters > 0 && predictiter+1 == dy_lp->d2.iters)
     { if (!atbnd(predicttotinf,starttotinf))
-      { warn(350,rtnnme,
+      { dywarn(350,rtnnme,
 	     dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	     "total",predicttotinf,predictiter,
 	     starttotinf,predicttotinf-starttotinf) ; }
       if (!atbnd(predictmaxinf,startmaxinf))
-      { warn(350,rtnnme,
+      { dywarn(350,rtnnme,
 	     dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	     "maximum",predictmaxinf,predictiter,
 	     startmaxinf,predictmaxinf-startmaxinf) ; } }
@@ -1260,7 +1260,7 @@ bool selectWithoutInf (int i, double *abari, dualcand_struct *incands,
     else
     if (dy_lp->d2.iters > 0 && predictiter+1 == dy_lp->d2.iters)
     { if (!atbnd(predictinf,startinf))
-      { warn(350,rtnnme,
+      { dywarn(350,rtnnme,
 	     dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	     "x<i>",predictinf,predictiter,startinf,predictinf-startinf) ; } }
   # endif
