@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 #define DYLP_INTERNAL
@@ -16,7 +16,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_force.c	4.6	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_force.c 243 2008-07-03 01:56:53Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_force.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 /*
   This file contains a pair of routines that attempt to force a transition
@@ -171,13 +171,14 @@ static int scanPrimVarDualInfeas (fdcand_struct **p_fdcands)
   flags statj ;
   bool purge ;
 
-# ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
 
   const char *rtnnme = "scanPrimVarDualInfeas" ;
 
   if (p_fdcands == NULL)
   { errmsg(2,rtnnme,"fdcands") ;
     return (-1) ; }
+
 # endif
 
 /*
@@ -543,16 +544,16 @@ dyphase_enum dy_forcePrimal2Dual (consys_struct *orig_sys)
 */
   if (suppressed == 0)
   { if (concnt == 0 && flgon(calcflgs,ladDUALFEAS))
-    { warn(439,rtnnme,
+    { dywarn(439,rtnnme,
 	   dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	   "absence","dual") ; } }
   else
   { if (flgoff(calcflgs,ladDUALFEAS))
-    { warn(439,rtnnme,
+    { dywarn(439,rtnnme,
 	   dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	   "presence","dual") ; } }
   if (dy_lp->simplex.active == dyDUAL && flgoff(calcflgs,ladPRIMFEAS))
-  { warn(439,rtnnme,
+  { dywarn(439,rtnnme,
 	 dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	 "presence","primal") ; }
 # endif
@@ -625,13 +626,14 @@ static int scanPrimConForceDeact (int **p_acndxs)
   flags statj ;
 
 
-# ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
 
   const char *rtnnme = "scanPrimConForceDeact" ;
 
   if (p_acndxs == NULL)
   { errmsg(2,rtnnme,"&acndxs") ;
     return (-1) ; }
+
 # endif
 
   m = dy_sys->concnt ;
@@ -913,12 +915,12 @@ dyphase_enum dy_forceDual2Primal (consys_struct *orig_sys)
 # ifdef DYLP_PARANOIA
   if (suppressed == 0)
   { if (varcnt == 0 && flgon(calcflgs,ladPRIMFEAS))
-    { warn(439,rtnnme,
+    { dywarn(439,rtnnme,
 	   dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	   "absence","primal") ; } }
   else
   { if (flgoff(calcflgs,ladPRIMFEAS))
-    { warn(439,rtnnme,
+    { dywarn(439,rtnnme,
 	   dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	   "presence","primal") ; } }
 # endif
@@ -965,7 +967,7 @@ static int scanPrimVarForceAct (consys_struct *orig_sys, int **p_ovndxs)
   int *ovndxs ;
 
 
-# ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
 
   const char *rtnnme = "scanPrimVarForceAct" ;
 
@@ -975,6 +977,7 @@ static int scanPrimVarForceAct (consys_struct *orig_sys, int **p_ovndxs)
   if (p_ovndxs == NULL)
   { errmsg(2,rtnnme,"&ovndxs") ;
     return (-1) ; }
+
 # endif
 
   n = orig_sys->varcnt ;
@@ -1041,7 +1044,7 @@ static int scanPrimConForceAct (consys_struct *orig_sys, int **p_ocndxs)
   int *ocndxs ;
 
 
-# ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
 
   const char *rtnnme = "scanPrimConForceAct" ;
 
@@ -1051,6 +1054,7 @@ static int scanPrimConForceAct (consys_struct *orig_sys, int **p_ocndxs)
   if (p_ocndxs == NULL)
   { errmsg(2,rtnnme,"&ocndxs") ;
     return (-1) ; }
+
 # endif
 
   m = orig_sys->concnt ;
