@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -55,7 +55,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_penalty.c	4.5	11/06/04" ;
-static char svnid[] UNUSED = "$Id: dy_penalty.c 246 2008-07-16 00:57:04Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_penalty.c 407 2010-12-31 20:48:48Z lou $" ;
 
 
 
@@ -202,8 +202,9 @@ bool dy_pricenbvars (lpprob_struct *orig_lp, flags priceme,
   call to initlclsystem will replace the client's copy of the original
   constraint system with the local scaled copy, if it exists.
 */
-  if (flgoff(orig_lp->ctlopts,lpctlDYVALID))
-  { errmsg(396,rtnnme,orig_lp->consys->nme,"price nonbasic columns") ;
+  if (orig_lp->owner != dy_owner)
+  { errmsg(396,rtnnme,orig_lp->consys->nme,
+  	   orig_lp->owner,dy_owner,"price nonbasic columns") ;
     return (FALSE) ; }
   (void) dy_initlclsystem(orig_lp,TRUE) ;
   orig_sys = orig_lp->consys ;
@@ -698,8 +699,9 @@ bool dy_pricedualpiv (lpprob_struct *orig_lp, int oxindx,
   Check for valid data structures, then pull out the constraint system. We want
   the client's (unscaled) copy, so we don't swap in the scaled local copy.
 */
-  if (flgoff(orig_lp->ctlopts,lpctlDYVALID))
-  { errmsg(396,rtnnme,orig_lp->consys->nme,"calculate penalty") ;
+  if (orig_lp->owner != dy_owner)
+  { errmsg(396,rtnnme,orig_lp->consys->nme,
+  	   orig_lp->owner,dy_owner,"calculate penalty") ;
     return (FALSE) ; }
   orig_sys = orig_lp->consys ;
 /*
