@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -30,7 +30,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_pivreject.c	4.4	11/06/04" ;
-static char svnid[] UNUSED = "$Id: dy_pivreject.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_pivreject.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 
 
@@ -108,7 +108,13 @@ void dy_initpivrej (int sze)
   Parameter:
     sze:	allocated capacity of the pivot rejection list
 */
-{ pivrej_ctl.sze = maxx(sze,5) ;
+{ 
+
+# if MALLOC_DEBUG == 2
+  char *rtnnme = "dy_initpivrej" ;
+# endif
+
+  pivrej_ctl.sze = maxx(sze,5) ;
   pivrejlst =
     (pivrej_struct *) MALLOC(pivrej_ctl.sze*sizeof(pivrej_struct)) ;
   pivrej_ctl.cnt = 0 ;
@@ -129,7 +135,12 @@ void dy_freepivrej (void)
   Free the pivot rejection list. Solely for information hiding.
 */
 
-{ if (pivrejlst != NULL)
+{ 
+# if MALLOC_DEBUG == 2
+  char *rtnnme = "dy_initpivrej" ;
+# endif
+
+  if (pivrejlst != NULL)
   { FREE(pivrejlst) ;
     pivrejlst = NULL ; }
   
@@ -553,7 +564,7 @@ dyret_enum dy_dealWithPunt (void)
     { 
 #     ifndef DYLP_NDEBUG
       if (dy_opts->print.pivreject >= 1)
-      { warn(376,rtnnme,
+      { dywarn(376,rtnnme,
 	     dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	     dy_tols->pivot,1/pivmul) ; }
 #     endif
@@ -586,7 +597,7 @@ dyret_enum dy_dealWithPunt (void)
     { 
 #     ifndef DYLP_NDEBUG
       if (dy_opts->print.pivreject >= 1)
-      { warn(383,rtnnme,dy_sys->nme,
+      { dywarn(383,rtnnme,dy_sys->nme,
 	     dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	     dy_tols->zero,dy_prtdyret(dyrPUNT)) ; }
 #     endif
