@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -38,7 +38,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_primalmultipivot.c	1.4	11/06/04" ;
-static char svnid[] UNUSED = "$Id: dy_primalmultipivot.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_primalmultipivot.c 407 2010-12-31 20:48:48Z lou $" ;
 
 /*
   The structure to hold pivot candidates
@@ -779,6 +779,10 @@ dyret_enum primmultiout (int j, int indir,
 
   primcand_struct *outcands,*candk ;
 
+# if MALLOC_DEBUG == 2
+  char *rtnnme = "dy_primmultiout" ;
+# endif
+
 /*
   Setup. Potentially, each basic variable can produce a soft and a hard pivot
   delta, and we need to allow for a bound-to-bound pivot. Hence we need a
