@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -21,7 +21,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_setup.c	4.7	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_setup.c 246 2008-07-16 00:57:04Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_setup.c 407 2010-12-31 20:48:48Z lou $" ;
 
 /*
   dyopts_dflt
@@ -401,7 +401,8 @@ void dy_defaults (lpopts_struct **opts, lptols_struct **tols)
 
 { 
 
-#ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
+
   const char *rtnnme = "dy_defaults" ;
 
   if (opts == NULL)
@@ -410,7 +411,8 @@ void dy_defaults (lpopts_struct **opts, lptols_struct **tols)
   if (tols == NULL)
   { errmsg(2,rtnnme,"&tols") ;
     return ; }
-#endif
+
+# endif
 
   if (*opts == NULL)
   { (*opts) = (lpopts_struct *) MALLOC(sizeof(lpopts_struct)) ; }
