@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -46,13 +46,14 @@
 
 #include "dylp.h"
 
-static char svnid[] UNUSED = "$Id: dy_tableau.c 302 2009-10-08 00:29:17Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_tableau.c 407 2010-12-31 20:48:48Z lou $" ;
 
 
 
 #if DYLP_PARANOIA > 0
 
-bool dy_std_paranoia (const lpprob_struct *orig_lp, const char *rtnnme)
+bool dy_std_paranoia (const lpprob_struct *orig_lp, const char *rtnnme,
+		      int line)
 /*
   Some standard paranoid checks for a call from outside, collected into one
   place.
@@ -86,9 +87,9 @@ bool dy_std_paranoia (const lpprob_struct *orig_lp, const char *rtnnme)
   Check that dylp and the lpprob_struct agree on whether dylp retains valid
   data structures.
 */
-  if ((flgoff(orig_lp->ctlopts,lpctlDYVALID) && dy_retained == TRUE) ||
-      (flgon(orig_lp->ctlopts,lpctlDYVALID) && dy_retained == FALSE))
-  { errmsg(1,rtnnme,__LINE__) ;
+  if ((flgoff(orig_lp->ctlopts,lpctlDYVALID) && dy_owner != NULL) ||
+      (flgon(orig_lp->ctlopts,lpctlDYVALID) && dy_owner == NULL))
+  { errmsg(1,rtnnme,line) ;
     return (FALSE) ; }
 
   return (TRUE) ; }
@@ -160,7 +161,7 @@ bool dy_betaj (lpprob_struct *orig_lp, int tgt_j, double **p_betaj)
   char *rtnnme = "dy_betaj" ;
 
 # if DYLP_PARANOIA > 0
-  if (dy_std_paranoia(orig_lp,rtnnme) == FALSE)
+  if (dy_std_paranoia(orig_lp,rtnnme,__LINE__) == FALSE)
   { return (FALSE) ; }
   if (p_betaj == NULL)
   { errmsg(2,rtnnme,"betaj") ;
@@ -169,8 +170,8 @@ bool dy_betaj (lpprob_struct *orig_lp, int tgt_j, double **p_betaj)
 /*
   Always check for valid data structures.
 */
-  if (flgoff(orig_lp->ctlopts,lpctlDYVALID))
-  { errmsg(396,rtnnme,orig_lp->consys->nme,
+  if (orig_lp->owner != dy_owner)
+  { errmsg(396,rtnnme,orig_lp->consys->nme,orig_lp->owner,dy_owner,
 	   "calculate column of basis inverse") ;
     return (FALSE) ; }
 
@@ -255,7 +256,7 @@ bool dy_betaj (lpprob_struct *orig_lp, int tgt_j, double **p_betaj)
   { if (*p_betaj == NULL)
     { *p_betaj = (double *) CALLOC((m_orig+1),sizeof(double)) ; }
     else
-    { memset(*p_betaj,0.0,((size_t) (m_orig+1)*sizeof(double))) ; }
+    { memset(*p_betaj,0,((size_t) (m_orig+1)*sizeof(double))) ; }
     (*p_betaj)[i_orig] = 1.0 ;
 #   ifndef DYLP_NDEBUG
     if (dy_opts->print.tableau >= 1)
@@ -336,7 +337,7 @@ bool dy_betaj (lpprob_struct *orig_lp, int tgt_j, double **p_betaj)
   { betaj = (double *) CALLOC((m_orig+1),sizeof(double)) ;
     *p_betaj = betaj ; }
   else
-  { memset(*p_betaj,0.0,((size_t) (m_orig+1)*sizeof(double))) ;
+  { memset(*p_betaj,0,((size_t)(m_orig+1)*sizeof(double))) ;
     betaj = *p_betaj ; }
   if (scaled == TRUE)
   { for (i = 1 ; i <= m ; i++)
@@ -437,6 +438,80 @@ bool dy_betaj (lpprob_struct *orig_lp, int tgt_j, double **p_betaj)
 */
   return (TRUE) ; }
 
+
+
+bool dy_betak (lpprob_struct *orig_lp, int orig_k, double **p_betak)
+/*
+  Given a basic column k, this routine returns the unscaled column of the
+  basis inverse, beta<k>.
+
+  Historically, this function was written well after dy_betaj, so we're going
+  to do something that looks odd: Given basis column orig_k, we'll determine
+  the index of the corresponding basic variable in the original system
+  context and call dy_betaj. As you'd expect, this isn't entirely trivial.
+  The column orig_k is specified in the context of the original system. Put
+  another way, the client is asking for the column corresponding to the
+  variable that's basic for constraint orig_k of the original system. So ...
+
+    1) Determine whether k is an active constraint.
+    2) If yes, consult dy_basis to determine the basic variable then translate
+       to the appropriate external constraint or variable index.
+       If no, then the associated logical is basic, and the appropriate
+       index is trivially -orig_k.
+
+  Parameters:
+    orig_lp:	lp problem structure
+    orig_k:	basis column index, in the original system context
+    p_betak:	(i) vector to hold beta<k>; if NULL, one will be allocated;
+		if non-NULL, will be cleared to zero.
+		(o) inv(B)e<k>, unscaled
+
+  Returns: TRUE if the calculation is successful, FALSE otherwise.
+*/
+
+{ int m,i,j,orig_j ;
+
+  char *rtnnme = "dy_betak" ;
+
+# if DYLP_PARANOIA > 0
+  if (dy_std_paranoia(orig_lp,rtnnme,__LINE__) == FALSE)
+  { return (FALSE) ; }
+  if (p_betak == NULL)
+  { errmsg(2,rtnnme,"betak") ;
+    return (FALSE) ; }
+# endif
+/*
+  Always check for valid data structures.
+*/
+  if (orig_lp->owner != dy_owner)
+  { errmsg(396,rtnnme,orig_lp->consys->nme,orig_lp->owner,dy_owner,
+	   "calculate column of basis inverse") ;
+    return (FALSE) ; }
+/*
+  Check to see whether constraint k is active.
+
+  If so, determine the index of the basic variable. First, get the constraint
+  index i in the active system, then get the index j of the basic variable.
+  If j is a logical, we need the index of the corresponding constraint in the
+  original system (negated), otherwise we need the index of the variable in the
+  original system.
+*/
+  m = dy_sys->concnt ;
+  if (ACTIVE_CON(orig_k))
+  { i = dy_origcons[orig_k] ;
+    j = dy_basis[i] ;
+    if (j <= m)
+    { orig_j = -dy_actcons[j] ; }
+    else
+    { orig_j = dy_actvars[j] ; } }
+/*
+  If k is inactive, then the associated logical is basic and the index is
+  trivially -orig_k
+*/
+  else
+  { orig_j = -orig_k ; }
+  
+  return (dy_betaj(orig_lp,orig_j,p_betak)) ; }
 
 
 
@@ -500,7 +575,7 @@ bool dy_abarj (lpprob_struct *orig_lp, int tgt_j, double **p_abarj)
   const char *rtnnme = "dy_abarj" ;
 
 # if DYLP_PARANOIA > 0
-  if (dy_std_paranoia(orig_lp,rtnnme) == FALSE)
+  if (dy_std_paranoia(orig_lp,rtnnme,__LINE__) == FALSE)
   { return (FALSE) ; }
   if (p_abarj == NULL)
   { errmsg(2,rtnnme,"abarj") ;
@@ -509,8 +584,8 @@ bool dy_abarj (lpprob_struct *orig_lp, int tgt_j, double **p_abarj)
 /*
   Always check for valid data structures.
 */
-  if (flgoff(orig_lp->ctlopts,lpctlDYVALID))
-  { errmsg(396,rtnnme,orig_lp->consys->nme,
+  if (orig_lp->owner != dy_owner)
+  { errmsg(396,rtnnme,orig_lp->consys->nme,orig_lp->owner,dy_owner,
 	   "calculate column of basis inverse") ;
     return (FALSE) ; }
 
@@ -761,7 +836,8 @@ bool dy_abarj (lpprob_struct *orig_lp, int tgt_j, double **p_abarj)
 			j_orig,k_orig,ai->coeffs[v].val) ; }
 #	  endif
 	  abarij += ai->coeffs[v].val*abarj[k_orig] ; } }
-      abarj[i_orig] = agj-abarij ; }
+      abarj[i_orig] = agj-abarij ;
+      setcleanzero(abarj[i_orig],dy_tols->zero) ; }
     if (ai != NULL) pkvec_free(ai) ; }
 
 # ifndef DYLP_NDEBUG
@@ -845,7 +921,7 @@ bool dy_betai (lpprob_struct *orig_lp, int tgt_i, double **p_betai)
 # endif
 
 # if DYLP_PARANOIA > 0
-  if (dy_std_paranoia(orig_lp,rtnnme) == FALSE)
+  if (dy_std_paranoia(orig_lp,rtnnme,__LINE__) == FALSE)
   { return (FALSE) ; }
   if (p_betai == NULL)
   { errmsg(2,rtnnme,"betai") ;
@@ -854,8 +930,9 @@ bool dy_betai (lpprob_struct *orig_lp, int tgt_i, double **p_betai)
 /*
   Always check for valid data structures.
 */
-  if (flgoff(orig_lp->ctlopts,lpctlDYVALID))
-  { errmsg(396,rtnnme,orig_lp->consys->nme,"calculate row of basis inverse") ;
+  if (orig_lp->owner != dy_owner)
+  { errmsg(396,rtnnme,orig_lp->consys->nme,orig_lp->owner,dy_owner,
+  	   "calculate row of basis inverse") ;
     return (FALSE) ; }
 /*
   Do a bit of setup. Pull constraint system sizes for convenient use. Grab the
@@ -1063,7 +1140,7 @@ bool dy_abari (lpprob_struct *orig_lp, int tgt_i, double **p_abari,
 # endif
 
 # if DYLP_PARANOIA > 0
-  if (dy_std_paranoia(orig_lp,rtnnme) == FALSE)
+  if (dy_std_paranoia(orig_lp,rtnnme,__LINE__) == FALSE)
   { return (FALSE) ; }
   if (p_abari == NULL)
   { errmsg(2,rtnnme,"abari") ;
@@ -1075,8 +1152,9 @@ bool dy_abari (lpprob_struct *orig_lp, int tgt_i, double **p_abari,
 /*
   Always check for valid data structures.
 */
-  if (flgoff(orig_lp->ctlopts,lpctlDYVALID))
-  { errmsg(396,rtnnme,orig_lp->consys->nme,"calculate row of basis inverse") ;
+  if (orig_lp->owner != dy_owner)
+  { errmsg(396,rtnnme,orig_lp->consys->nme,orig_lp->owner,dy_owner,
+  	   "calculate row of basis inverse") ;
     return (FALSE) ; }
 /*
   Do a bit of setup. Pull constraint system sizes for convenient use.
@@ -1153,7 +1231,8 @@ bool dy_abari (lpprob_struct *orig_lp, int tgt_i, double **p_abari,
 	else
 	{ abari[j_orig] = 0.0 ; }
 	continue ; } }
-    abari[j_orig] = consys_dotcol(orig_sys,j_orig,betai) ; }
+    abari[j_orig] = consys_dotcol(orig_sys,j_orig,betai) ;
+    setcleanzero(abari[j_orig],dy_tols->zero) ; }
 
 # ifndef DYLP_NDEBUG
   if (dy_opts->print.tableau >= 4)
