@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -79,7 +79,7 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dy_varmgmt.c	4.6	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dy_varmgmt.c 240 2008-06-18 23:32:21Z lou $" ;
+static char svnid[] UNUSED = "$Id: dy_varmgmt.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 
 
@@ -837,7 +837,7 @@ static int scanPrimVarStdDeact (int **p_avndxs)
   flags statj ;
   bool purge ;
 
-# ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
   const char *rtnnme = "scanPrimVarStdDeact" ;
 
   if (p_avndxs == NULL)
@@ -987,7 +987,7 @@ static int scanPrimVarStdAct (consys_struct *orig_sys,
   bool fatal,use_all,activate ;
   flags statj ;
 
-# ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
   const char *rtnnme = "scanPrimVarStdAct" ;
 
   if (orig_sys == NULL)
@@ -1381,12 +1381,12 @@ int dy_activateVars (consys_struct *orig_sys, int *preset)
 */
 	if (dy_lp->simplex.next == dyDUAL)
 	{ if (flgon(calcflgs,ladDUALFEAS))
-	  { warn(439,rtnnme,
+	  { dywarn(439,rtnnme,
 		 dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 		 "loss","dual") ; } }
 	else
 	{ if (flgoff(calcflgs,ladDUALFEAS))
-	  { warn(439,rtnnme,
+	  { dywarn(439,rtnnme,
 		 dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 		 "gain","dual") ; } }
 #	endif
