@@ -1,14 +1,14 @@
 /*
   This file is a part of the Dylp LP distribution.
 
-        Copyright (C) 2005 -- 2007 Lou Hafer
+        Copyright (C) 2005 -- 2010 Lou Hafer
 
         School of Computing Science
         Simon Fraser University
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -20,7 +20,32 @@
 #include "dylp.h"
 
 static char sccsid[] UNUSED = "@(#)dylp_io.c	4.5	11/06/04" ;
-static char svnid[] UNUSED = "$Id: dylp_io.c 243 2008-07-03 01:56:53Z lou $" ;
+static char svnid[] UNUSED = "$Id: dylp_io.c 407 2010-12-31 20:48:48Z lou $" ;
+
+
+/*
+  Output control variables
+
+  dy_logchn:	log file
+  dy_gtxecho:	true if generated text should also be echoed to stdout
+
+  Mostly these are simply passed as parameters to dylib_io routines that
+  generate output. Dylib_io ensures that output goes to the log file and/or
+  stdout as required.
+*/
+
+ioid dy_logchn = IOID_NOSTRM ;
+bool dy_gtxecho = FALSE ;
+
+/*
+  And a pair of routines whose sole purpose in life is to allow dy_logchn and
+  dy_gtxecho to remain hidden inside of libdylp.
+*/
+
+void dy_setlogchn (ioid chn) { dy_logchn = chn ; }
+
+void dy_setgtxecho (bool echo) { dy_gtxecho = echo ; }
+
 
 
 
