@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -22,7 +22,7 @@
 #include <limits.h>
 
 static char sccsid[] UNUSED = "@(#)dylp_utils.c	4.6	10/15/05" ;
-static char svnid[] UNUSED = "$Id: dylp_utils.c 299 2009-08-28 01:35:28Z lou $" ;
+static char svnid[] UNUSED = "$Id: dylp_utils.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 
 
@@ -289,7 +289,7 @@ bool dy_calcprimals (void)
 		     dy_x[vndx],"fix",fabs(dy_sys->vub[vndx]-xvec[bndx]),
 		     dy_tols->pfeas*100) ; }
 	    else
-	    { warn(333,rtnnme,dy_sys->nme,
+	    { dywarn(333,rtnnme,dy_sys->nme,
 		   dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 		   consys_nme(dy_sys,'v',vndx,FALSE,NULL),vndx,
 		   dy_prtvstat(dy_status[vndx]),xvec[bndx],
@@ -531,7 +531,7 @@ dyret_enum dy_updateprimals (int j, double deltaj, double *p_abarj)
       { retval = dyrREQCHK ;
 #       ifndef DYLP_NDEBUG
 	if (dy_opts->print.pivoting >= 1)
-	  warn(374,rtnnme,dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),
+	  dywarn(374,rtnnme,dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),
 	       dy_lp->tot.iters,"x",k,fabs(newxk),eps0*dy_tols->bogus,
 	       eps0*dy_tols->bogus-newxk) ;
 #       endif
@@ -541,7 +541,7 @@ dyret_enum dy_updateprimals (int j, double deltaj, double *p_abarj)
       { retval = dyrREQCHK ;
 #	ifndef DYLP_NDEBUG
 	if (dy_opts->print.pivoting >= 1)
-	  warn(375,rtnnme,dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),
+	  dywarn(375,rtnnme,dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),
 	       dy_lp->tot.iters,"lb",k,"x",k,
 	       lbk,newxk,lbk-newxk,epsl*dy_tols->bogus,
 	       epsl*dy_tols->bogus-(lbk-newxk)) ;
@@ -552,7 +552,7 @@ dyret_enum dy_updateprimals (int j, double deltaj, double *p_abarj)
       { retval = dyrREQCHK ;
 #       ifndef DYLP_NDEBUG
 	if (dy_opts->print.pivoting >= 1)
-	{ warn(375,rtnnme,dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),
+	{ dywarn(375,rtnnme,dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),
 	       dy_lp->tot.iters,"ub",k,"x",k,
 	       ubk,newxk,ubk-newxk,epsu*dy_tols->bogus,
 	       epsu*dy_tols->bogus-(ubk-newxk)) ; }
@@ -977,13 +977,13 @@ bool dy_calccbar (void)
 #   ifndef DYLP_PARANOIA
 /* The expedient decision: basic or not? */
     if (dy_var2basis[xjndx] > 0)
-    { dy_cbar[xjndx] = 0 ;
+    { dy_cbar[xjndx] = 0.0 ;
       continue ; }
 #   else
 /* The cautious decision (when available). */
     if (dy_lp->phase == dyINIT)
     { if (dy_var2basis[xjndx] > 0)
-      { dy_cbar[xjndx] = 0 ;
+      { dy_cbar[xjndx] = 0.0 ;
 	continue ; } }
     else
     { xjstatus = dy_status[xjndx] ;
@@ -1086,6 +1086,9 @@ void dy_dseinit (void)
 { int xkpos ;
   double *betak ;
 
+# if MALLOC_DEBUG == 2
+  char *rtnnme = "dy_dseinit" ;
+# endif
 # ifndef DYLP_NDEBUG
   if (dy_opts->print.dual >= 2)
   { dyio_outfmt(dy_logchn,dy_gtxecho,
@@ -1255,7 +1258,7 @@ bool dy_chkstatus (int vndx)
       if (primDegen == FALSE)
       { if (!withintol(xbk,xk,dy_tols->zero*(1.0+fabs(xbk))))
 	{ if (withintol(xbk,xk,10*dy_tols->zero*(1.0+fabs(xbk))))
-	  { warn(332,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,xk,xbk,
+	  { dywarn(332,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,xk,xbk,
 		   fabs(xk-xbk),dy_tols->zero*(1.0+fabs(xbk))) ; }
 	  else
 	  { errmsg(332,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,xk,xbk,
@@ -1271,7 +1274,7 @@ bool dy_chkstatus (int vndx)
 */
 	else
 	if (xbk != xk)
-	{ warn(332,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,xk,xbk,
+	{ dywarn(332,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,xk,xbk,
 	       fabs(xk-xbk),0.0) ; }
 #	endif
       } }
@@ -1325,7 +1328,7 @@ bool dy_chkstatus (int vndx)
 		   xbk,ubk,"lb = ub",fabs(xbk-ubk),bogusu) ;
 	    retval = FALSE ; }
 	  else
-	  { warn(333,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(333,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 xbk,ubk,"lb = ub",fabs(xbk-ubk),tolu) ; } }
 	break ; }
       case vstatBUUB:
@@ -1335,11 +1338,11 @@ bool dy_chkstatus (int vndx)
 		   lbk,xbk,ubk,ubk-xbk,bogusu+tolu) ;
 	    retval = FALSE ; }
 	  else
-	  { warn(335,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(335,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 lbk,xbk,ubk,ubk-xbk,tolu) ; } }
 	else
 	if (dy_lp->phase == dyPRIMAL2)
-	  warn(323,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  dywarn(323,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 	       lbk,xbk,ubk,xbk-ubk,tolu) ;
 	break ; }
       case vstatBUB:
@@ -1349,7 +1352,7 @@ bool dy_chkstatus (int vndx)
 		   xbk,ubk,"ub",ubk-xbk,bogusu) ;
 	    retval = FALSE ; }
 	  else
-	  { warn(333,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(333,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 xbk,ubk,"ub",ubk-xbk,tolu) ; } }
 	break ; }
       case vstatB:
@@ -1365,11 +1368,11 @@ bool dy_chkstatus (int vndx)
 	    retval = FALSE ; }
 	  else
 	  if (xbk < lbk+toll)
-	  { warn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 lbk,xbk,ubk,lbk-xbk,toll) ; }
 	  else
 	  if (xbk > ubk-tolu)
-	  { warn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 lbk,xbk,ubk,xbk-ubk,tolu) ; } }
 	break ; }
       case vstatSB:
@@ -1385,11 +1388,11 @@ bool dy_chkstatus (int vndx)
 	    retval = FALSE ; }
 	  else
 	  if (xk < lbk+toll)
-	  { warn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 lbk,xk,ubk,lbk-xk,toll) ; }
 	  else
 	  if (xk > ubk-tolu)
-	  { warn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(322,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 lbk,xk,ubk,xbk-ubk,tolu) ; } }
 	break ; }
       case vstatBLB:
@@ -1399,7 +1402,7 @@ bool dy_chkstatus (int vndx)
 		   xbk,lbk,"lb",xbk-lbk,bogusl) ;
 	    retval = FALSE ; }
 	  else
-	  { warn(333,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(333,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 xbk,lbk,"lb",xbk-lbk,toll) ; } }
 	break ; }
       case vstatBLLB:
@@ -1409,11 +1412,11 @@ bool dy_chkstatus (int vndx)
 		   lbk,xbk,ubk,xbk-lbk,bogusl+toll) ;
 	    retval = FALSE ; }
 	  else
-	  { warn(335,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  { dywarn(335,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 		 lbk,xbk,ubk,xbk-lbk,toll) ; } }
 	else
 	if (dy_lp->phase == dyPRIMAL2)
-	  warn(323,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
+	  dywarn(323,rtnnme,dy_sys->nme,phase,iter,nmek,xkndx,statk,
 	       lbk,xbk,ubk,lbk-xbk,toll) ;
 	break ; }
       case vstatBFR:
@@ -1563,7 +1566,7 @@ void dy_chkdual (int lvl)
     { diff = fabs(dy_y[i]-y[i]) ;
       if (diff > tol)
       { if (lvl >= 2)
-	{ warn(321,rtnnme,
+	{ dywarn(321,rtnnme,
 	       dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	       (dy_lp->degen == 0)?"real":"uninvolved",
 	       "dy_y",i,dy_y[i],y[i],diff,tol) ; }
@@ -1572,7 +1575,7 @@ void dy_chkdual (int lvl)
     else
     { if (fabs(y[i]) > tol)
       { if (lvl >= 2)
-	{ warn(321,rtnnme,
+	{ dywarn(321,rtnnme,
 	       dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	       "real","y",i,y[i],0.0,y[i],tol) ; }
 	yerrcnt++ ;
@@ -1590,7 +1593,7 @@ void dy_chkdual (int lvl)
     { diff = fabs(dy_cbar[j]-cbar[j]) ;
       if (diff > tol)
       { if (lvl >= 2)
-	{ warn(321,rtnnme,
+	{ dywarn(321,rtnnme,
 	       dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	       (dy_lp->degen == 0)?"real":"uninvolved",
 	       "dy_cbar",j,dy_cbar[j],cbar[j],diff,tol) ; }
@@ -1599,7 +1602,7 @@ void dy_chkdual (int lvl)
     else
     { if (fabs(cbar[j]) > tol)
       { if (lvl >= 2)
-	{ warn(321,rtnnme,
+	{ dywarn(321,rtnnme,
 	       dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	       "real","cbar",j,cbar[j],0.0,cbar[j],tol) ; }
       cbarerrcnt++ ;
@@ -1620,7 +1623,7 @@ void dy_chkdual (int lvl)
       yi = y[i] ;
       if (fabs(cbarj+yi) > base_tol)
       { if (lvl >= 2)
-	{ warn(336,rtnnme,
+	{ dywarn(336,rtnnme,
 	       dy_sys->nme,dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	       consys_nme(dy_sys,'v',i,FALSE,NULL),i,dy_prtvstat(statj),
 	       "real",-yi,cbarj,fabs(cbarj+yi),base_tol) ; }
@@ -1638,7 +1641,7 @@ void dy_chkdual (int lvl)
 	(flgon(statj,vstatNBUB) && cbarj > dy_tols->dfeas) ||
 	(flgon(statj,vstatNBFR) && cbarj != 0) || flgon(statj,vstatSB))
     { if (lvl >= 2)
-      { warn(347,rtnnme,dy_sys->nme,
+      { dywarn(347,rtnnme,dy_sys->nme,
 	     dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	     consys_nme(dy_sys,'v',j,FALSE,NULL),j,
 	       dy_prtvstat(statj),j,cbarj,dy_tols->dfeas) ; }
@@ -1649,7 +1652,7 @@ void dy_chkdual (int lvl)
 	  (flgon(statj,vstatNBUB) && cbarj > dy_tols->dfeas) ||
 	  (flgon(statj,vstatNBFR) && cbarj != 0) || flgon(statj,vstatSB))
       { if (lvl >= 2)
-	{ warn(347,rtnnme,dy_sys->nme,
+	{ dywarn(347,rtnnme,dy_sys->nme,
 	       dy_prtlpphase(dy_lp->phase,TRUE),dy_lp->tot.iters,
 	       consys_nme(dy_sys,'v',j,FALSE,NULL),j,
 		 dy_prtvstat(statj),j,cbarj,dy_tols->dfeas) ; }
@@ -1964,7 +1967,7 @@ bool dy_chkdysys (consys_struct *orig_sys)
     if (!withintol(dy_sys->rhs[acndx],orig_sys->rhs[ocndx]-rhscorr,scaledtol))
     { if (withintol(dy_sys->rhs[acndx],
 		    orig_sys->rhs[ocndx]-rhscorr,10*scaledtol))
-      { warn(366,rtnnme,dy_sys->nme,acndx,dy_sys->rhs[acndx],
+      { dywarn(366,rtnnme,dy_sys->nme,acndx,dy_sys->rhs[acndx],
 	     consys_nme(dy_sys,'c',acndx,FALSE,NULL),
 	     orig_sys->rhs[ocndx]-rhscorr,
 	     fabs(dy_sys->rhs[acndx]-(orig_sys->rhs[ocndx]-rhscorr)),
@@ -2031,7 +2034,7 @@ bool dy_dupbasis (int dst_basissze, basis_struct **p_dst_basis,
   bool want_basis,want_status ;
 
 
-# ifdef DYLP_PARANOIA
+# if defined(DYLP_PARANOIA) || MALLOC_DEBUG == 2
   const char *rtnnme = "dy_dupbasis" ;
 
   if (p_dst_basis == NULL && p_dst_status == NULL)
@@ -2073,7 +2076,7 @@ bool dy_dupbasis (int dst_basissze, basis_struct **p_dst_basis,
     if (dst_basissze < src_basis->len)
     {
 #     ifdef DYLP_PARANOIA
-      warn(404,rtnnme,"basis",dst_basissze,src_basis->len) ;
+      dywarn(404,rtnnme,"basis",dst_basissze,src_basis->len) ;
 #     endif
       dst_basissze = src_basis->len ; }
     if (dst_basis->el == NULL)
@@ -2093,7 +2096,7 @@ bool dy_dupbasis (int dst_basissze, basis_struct **p_dst_basis,
       if (dst_statussze < src_statuslen)
       {
 #       ifdef DYLP_PARANOIA
-	warn(404,rtnnme,"status",dst_statussze,src_statuslen) ;
+	dywarn(404,rtnnme,"status",dst_statussze,src_statuslen) ;
 #       endif
 	dst_statussze = src_statuslen ; }
       *p_dst_status = (flags *) MALLOC((dst_statussze+1)*sizeof(flags)) ; }
@@ -2280,7 +2283,7 @@ static void build_soln (lpprob_struct *orig_lp)
 		   dy_prtvstat(xjstatus)) ;
 #         ifndef DYLP_NDEBUG
 	  else
-	    warn(359,rtnnme,dy_sys->nme,
+	    dywarn(359,rtnnme,dy_sys->nme,
 		 consys_nme(dy_sys,'v',xjndx,FALSE,NULL),xjndx,
 		 dy_prtvstat(xjstatus)) ;
 #         endif
@@ -2336,64 +2339,63 @@ void dy_finishup (lpprob_struct *orig_lp, dyphase_enum phase)
 */
 
 { consys_struct *orig_sys ;
+  bool freeStructs = TRUE ;
 
-  extern bool dy_retained ;		/* dylp.c */
+# if MALLOC_DEBUG == 2
+  char *rtnnme = "dy_finishup" ;
+# endif
 
 /*
   Why are we here?
 
-  It may be that the user called dylp strictly to free the data structures;
-  this is indicated by orig_lp->phase == dyDONE, phase == dyINV, and the
-  lpctlONLYFREE flag.
+  There are a couple of calls that are possible very early in initialisation
+  (indicated by a phase of dyINV):
+  * It may be that the user called dylp strictly to free the data structures;
+    this is indicated by orig_opts->context == cxUNLOAD.
+  * The constraint system may have been flagged as corrupt, or some paranoid
+    check failed.
+  * It may be that dylp needs to free up previous data structures in
+    preparation for a warm or cold start.
 
-  It may be that dylp needs to free up previous data structures to do a warm
-  or cold start. This is indicated by orig_lp->phase == dyINIT and phase ==
-  dyINIT and orig_lp->lpret == dyINV.
+  In the above situations, the call to initlclsystem exposes any
+  retained local system for deletion. Later in the run, we don't need this.
 
   Otherwise, if orig_lp->phase is dyDONE,  we're cleanly done and we'll try
   to build an answer as best we can.  `Cleanly done' covers error and
-  non-error returns.
+  non-error returns, but we only retain data structures if the client requests
+  it and the result is such that their might be some use in it (e.g., hot
+  start after modification, requests for tableau vectors, etc.). This is a bit
+  subjective; currently limited to the four possibilities listed below.
 
   Anything else is a serious error, and we won't even attempt to build a
   solution, just free the data structures.
 */
-  if (orig_lp->phase == dyDONE && phase == dyINV &&
-      flgon(orig_lp->ctlopts,lpctlONLYFREE))
-  { clrflg(orig_lp->ctlopts,lpctlACTVARSOUT) ;
-    dy_initlclsystem(orig_lp,TRUE) ; }
-  else
-  if (orig_lp->phase == dyINIT && phase == dyINIT && orig_lp->lpret == dyINV)
+  if (phase == dyINV)
   { dy_initlclsystem(orig_lp,TRUE) ; }
   else
-  if (orig_lp->phase == dyDONE)
-  { build_soln(orig_lp) ; }
-  else
-  { clrflg(orig_lp->ctlopts,lpctlACTVARSOUT) ; }
+  if (orig_lp->phase == dyDONE && orig_lp->lpret != lpFATAL)
+  { build_soln(orig_lp) ;
+    if (flgon(orig_lp->ctlopts,lpctlNOFREE) &&
+	(orig_lp->lpret == lpOPTIMAL || orig_lp->lpret == lpUNBOUNDED ||
+	 orig_lp->lpret == lpINFEAS || orig_lp->lpret == lpITERLIM))
+    { freeStructs = FALSE ; } }
 /*
   Free up the working structures --- the constraint system and the various
   local vectors, the LP control structure, and the option and tolerance
   structures. We also need to detach origvars and origcons from orig_sys, so
   that we don't keep accumulating attachment structures. The code is
-  defensive, setting all pointers back to NULL so that we don't get in
-  trouble in an environment (like COIN) where multiple cleanup calls are
-  possible from independent objects.
-
-  The exception is if we see the lpctlNOFREE flag and we've come to one of
-  the mathematically valid results --- optimal, unbounded, or infeasible.
-  In this case, we can support reoptimisation with a hot start. Add to these
-  the case of lpITERLIM, which is a valid state of affairs and occurs fairly
-  commonly in branch & cut applications (e.g., strong branching).
+  defensive, setting all pointers back to NULL so that there's no ambiguity.
 */
-  if (flgoff(orig_lp->ctlopts,lpctlNOFREE) ||
-      (!(orig_lp->lpret == lpOPTIMAL || orig_lp->lpret == lpUNBOUNDED ||
-	 orig_lp->lpret == lpINFEAS || orig_lp->lpret == lpITERLIM)))
+  if (freeStructs == TRUE)
   { orig_sys = orig_lp->consys ;
     if (dy_origvars != NULL)
-    { (void) consys_detach(orig_sys,(void **) &dy_origvars,TRUE) ;
+    { if (orig_sys != NULL)
+        (void) consys_detach(orig_sys,(void **) &dy_origvars,TRUE) ;
       FREE(dy_origvars) ;
       dy_origvars = NULL ; }
     if (dy_origcons != NULL)
-    { (void) consys_detach(orig_sys,(void **) &dy_origcons,TRUE) ;
+    { if (orig_sys != NULL)
+        (void) consys_detach(orig_sys,(void **) &dy_origcons,TRUE) ;
       FREE(dy_origcons) ;
       dy_origcons = NULL ; }
     dy_freelclsystem(orig_lp,TRUE) ;
@@ -2421,11 +2423,16 @@ void dy_finishup (lpprob_struct *orig_lp, dyphase_enum phase)
     FREE_AND_CLEAR(dy_tols)
     FREE_AND_CLEAR(dy_opts)
     clrflg(orig_lp->ctlopts,lpctlDYVALID) ;
-    dy_retained = FALSE ; }
+    orig_lp->fullsys = FALSE ;
+    dy_owner = NULL ; }
   else
   { setflg(orig_lp->ctlopts,lpctlDYVALID) ;
+    if (dy_lp->sys.cons.loadable == 0 && dy_lp->sys.vars.loadable == 0)
+      orig_lp->fullsys = TRUE ;
+    else
+      orig_lp->fullsys = FALSE ;
     dy_freelclsystem(orig_lp,FALSE) ;
-    dy_retained = TRUE ; }
+    dy_owner = orig_lp->owner ; }
 
   return ; }
 
@@ -2445,7 +2452,13 @@ void dy_freesoln (lpprob_struct *lpprob)
   Returns: undefined
 */
 
-{ if (lpprob->basis != NULL)
+{
+
+# if MALLOC_DEBUG == 2
+  char *rtnnme = "dy_freesoln" ;
+# endif
+
+  if (lpprob->basis != NULL)
   { if (lpprob->basis->el != NULL) FREE(lpprob->basis->el) ;
     FREE(lpprob->basis) ;
     lpprob->basis = NULL ; }
