@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -26,7 +26,7 @@
 #include "dylib_std.h"
 
 static char sccsid[] UNUSED = "@(#)bnfrdr.c	3.9	09/25/04" ;
-static char svnid[] UNUSED = "$Id: dylib_bnfrdr.c 238 2008-06-03 06:14:45Z lou $" ;
+static char svnid[] UNUSED = "$Id: dylib_bnfrdr.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 #include "dylib_io.h"
 #include "dylib_errs.h"
@@ -215,7 +215,7 @@ static const char *strretrv (int ndx)
 */
 
 #define offset_in_range(qq_off,qq_sze) \
-	(((qq_off) >= 0 && (qq_off) <= cndesze - (qq_sze))?TRUE:FALSE)
+	(((qq_off) >= 0 && (qq_off) <= cndesze - ((int)(qq_sze)))?TRUE:FALSE)
 
 #define max_offset(qq_sze) \
 	(cndesze - (qq_sze))
@@ -390,8 +390,8 @@ void rdrclear (void)
   { FREE(newtxt) ;
     newtxt = NULL ; }
 
-  if (curnde != NULL) warn(71,rtnnme,"curnde") ;
-  if (curtxt != NULL) warn(71,rtnnme,"curtxt") ;
+  if (curnde != NULL) dywarn(71,rtnnme,"curnde") ;
+  if (curtxt != NULL) dywarn(71,rtnnme,"curtxt") ;
   
   return ; }
 
@@ -1575,7 +1575,7 @@ bool dolabel (bnfLBref_struct *ref)
 
 # ifndef DYLP_NDEBUG
   if (lblval == NULL && warnzlbl == TRUE)
-    warn(58,rtnnme,nmtxt) ;
+    dywarn(58,rtnnme,nmtxt) ;
   if (debug > 0)
   { printtab(dbgchn,dbgecho,nestlvl,numlvl,tablvl) ;
     dyio_outfmt(dbgchn,dbgecho,"[ value: %#1x ]\n",nmtxt) ;
@@ -1790,7 +1790,7 @@ bool doreference (bnfLBref_struct *ref)
 
 # ifndef DYLP_NDEBUG
   if (warnzlbl == TRUE && val == NULL && val_valid == TRUE)
-    warn(65,rtnnme) ;
+    dywarn(65,rtnnme) ;
   if (debug > 0)
   { printtab(dbgchn,dbgecho,nestlvl,numlvl,tablvl) ;
     dyio_outfmt(dbgchn,dbgecho,"[ \"%s\" = %#1x ]\n",nmtxt) ;
@@ -1906,7 +1906,7 @@ bool dolist (bnfref_any ref)
 	{ errmsg(30,rtnnme,ref.G->offset,max_offset(sizeof(void *))) ;
 	  return (FALSE) ; } }
       if (def.G->link < 0 ||
-	  def.G->link > def.G->size - sizeof(void *))
+	  def.G->link > def.G->size - ((int) sizeof(void *)))
       { errmsg(69,rtnnme,def.G->link,def.G->size-sizeof(void *)) ;
 	return (FALSE) ; }
       savcnde = curnde ;
