@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -37,7 +37,7 @@
 #include "dylib_std.h"
 
 static char sccsid[] UNUSED = "@(#)errs.c	3.13	11/11/04" ;
-static char svnid[] UNUSED = "$Id: dylib_errs.c 244 2008-07-03 02:39:05Z lou $" ;
+static char svnid[] UNUSED = "$Id: dylib_errs.c 524 2013-12-15 03:59:57Z tkr $" ;
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -76,6 +76,11 @@ static char warntxt[MAXERRTXT+WARNPFXLEN] = "\n%s (warning): " ;
   Only errmsg_, warn_, and a small bit of initialisation in errinit need the
   declarations of fortran.h. The file xmp.h is peculiar to the bonsai code
   with Fortran ylp and la05 libraries.
+
+  WARNING!
+
+  The Fortran hooks haven't been tested since the last millenium. It's highly
+  unlikely that they still work.
 */
 
 #ifdef _DYLIB_FORTRAN
@@ -428,21 +433,25 @@ void errmsg (int errid, ... )
   the error number. Otherwise call vfprintf to handle expanding the message
   text.
 */
-  va_start(varargs,errid) ; 
   if (emsgchn == NULL || finderrmsg(errid,&errtxt[ERRPFXLEN]) == NULL)
-  { ident = va_arg(varargs,char *) ;
+  { va_start(varargs,errid) ; 
+    ident = va_arg(varargs,char *) ;
     if (errecho == TRUE)
       fprintf(stderr,"\n%s: error %d.\n",ident,errid) ;
     if (elogchn != NULL)
-      fprintf(elogchn,"\n%s: error %d.\n",ident,errid) ; }
+      fprintf(elogchn,"\n%s: error %d.\n",ident,errid) ;
+    va_end(varargs) ; }
   else
   { if (errecho == TRUE)
-    { vfprintf(stderr,errtxt,varargs) ;
-      putc('\n',stderr) ; }
+    { va_start(varargs,errid) ;
+      vfprintf(stderr,errtxt,varargs) ;
+      putc('\n',stderr) ;
+      va_end(varargs) ; }
     if (elogchn != NULL) 
-    { vfprintf(elogchn,errtxt,varargs) ;
-      putc('\n',elogchn) ; } }
-  va_end(varargs) ;
+    { va_start(varargs,errid) ;
+      vfprintf(elogchn,errtxt,varargs) ;
+      putc('\n',elogchn) ;
+      va_end(varargs) ; } }
 /*
   Flush the logged error message, so that the user will definitely see it.
 */
@@ -454,17 +463,17 @@ void errmsg (int errid, ... )
 
 #ifdef DYLP_NDEBUG
 
-void warn (int errid, ... )
+void dywarn (int errid, ... )
 
 { return ; }
 
 #else
 
-void warn (int errid, ... )
+void dywarn (int errid, ... )
 
 /*
   Actual Call:
-    warn(errid,ident,arg1, ... ,argn)
+    dywarn(errid,ident,arg1, ... ,argn)
 
   Warn is functionally identical to errmsg, but prints the message
   "ident (warning): warning message".
@@ -492,21 +501,25 @@ void warn (int errid, ... )
   the error number. Otherwise call vfprintf to handle expanding the message
   text.
 */
-  va_start(varargs,errid) ; 
   if (emsgchn == NULL || finderrmsg(errid,&warntxt[WARNPFXLEN]) == NULL)
-  { ident = va_arg(varargs,char *) ;
+  { va_start(varargs,errid) ; 
+    ident = va_arg(varargs,char *) ;
     if (errecho == TRUE)
       fprintf(stderr,"\n%s: error %d.\n",ident,errid) ;
     if (elogchn != NULL)
-      fprintf(elogchn,"\n%s: error %d.\n",ident,errid) ; }
+      fprintf(elogchn,"\n%s: error %d.\n",ident,errid) ;
+    va_end(varargs) ; }
   else
   { if (errecho == TRUE)
-    { vfprintf(stderr,warntxt,varargs) ;
-      putc('\n',stderr) ; }
+    { va_start(varargs,errid) ;  
+      vfprintf(stderr,warntxt,varargs) ;
+      putc('\n',stderr) ;
+      va_end(varargs) ; }
     if (elogchn != NULL) 
-    { vfprintf(elogchn,warntxt,varargs) ;
-      putc('\n',elogchn) ; } }
-  va_end(varargs) ;
+    { va_start(varargs,errid) ; 
+      vfprintf(elogchn,warntxt,varargs) ;
+      putc('\n',elogchn) ;
+      va_end(varargs) ; } }
 /*
   Flush the logged error message, so that the user will definitely see it.
 */
@@ -517,9 +530,18 @@ void warn (int errid, ... )
 #endif /* DYLP_NDEBUG */
 
 #ifdef _DYLIB_FORTRAN
-
 
 
+/*
+  WARNING!
+
+  The Fortran hooks haven't been tested since the last millenium. It's highly
+  unlikely that they still work. In current implementations, it's necessary
+  to bracket each use of the varargs block by vfprintf with va_start / va_end,
+  as in the errmsg and warn functions above. This is because use of the
+  va_start macro steps the va_list pointer to the next argument.
+*/
+
 /*
   The two routines which follow, errmsg_ and warn_, are intended to be
   called from Fortran code. (The is also a companion routine, io.c:outfmt_.)
@@ -698,7 +720,7 @@ void warn_ (integer *errid, char *ident, ... )
   above, the method used is a little dubious.
 
   The call, over in Fortran, looks something like
-    warn(errno,rtnnme,ftnargtype1,arg1, ... ,ftnargtypen,argn,ftnargEND)
+    dywarn(errno,rtnnme,ftnargtype1,arg1, ... ,ftnargtypen,argn,ftnargEND)
 
   By the time it gets here, of course, it's all pointers, and there are
   additional arguments tacked on at the end for character string lengths.
