@@ -11,12 +11,12 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
   sccs: @(#)errs.h	2.3	03/18/04
-  svn/cvs: $Id: dylib_errs.h 148 2007-06-09 03:15:30Z lou $
+  svn/cvs: $Id: dylib_errs.h 590 2016-07-25 15:22:42Z tkr $
 */
 
 #include "dylib_std.h"
@@ -28,11 +28,11 @@ void errinit(const char *emsgpath, const char *elogpath, bool errecho),
      errterm(void) ;
 
 void errmsg(int errid, ... ),
-       warn(int errid, ... ) ;
+     dywarn(int errid, ... ) ;
 
 #ifdef _DYLIB_FORTRAN
 void errmsg_(integer *errid, char *ident, ... ) ;
-void warn_(integer *errid, char *ident, ... ) ;
+void dywarn_(integer *errid, char *ident, ... ) ;
 #endif
 
 #endif /* _DYLIB_ERRS_H */
