@@ -10,7 +10,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*                Hash Table Structures                 */
@@ -21,7 +21,7 @@
   is maintained is the association between a key and some generic object.
 
   @(#)hash.h	1.3 06/22/04
-  svn/cvs: $Id: dylib_hash.h 148 2007-06-09 03:15:30Z lou $
+  svn/cvs: $Id: dylib_hash.h 407 2010-12-31 20:48:48Z lou $
 */
 
 /* 
@@ -40,9 +40,11 @@ typedef struct hel_tag { struct hel_tag *next ;
 
 /* Hash table interface routines */
 
-extern void *lookup(const char *key, hel *hashtab[], int size),
-            *search(const char *key, hel *hashtab[], int size, bool init),
-	    *enter(const char *key, hel *hashtab[], int size, void *entry),
-	    *erase(const char *key, hel *hashtab[], int size) ;
+extern void *dyhash_lookup(const char *key, hel *hashtab[], int size),
+            *dyhash_search(const char *key, hel *hashtab[],
+	    		   int size, bool init),
+	    *dyhash_enter(const char *key, hel *hashtab[],
+	    		  int size, void *entry),
+	    *dyhash_erase(const char *key, hel *hashtab[], int size) ;
 
 #endif /* _DYLIB_HASH_H */
