@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -28,7 +28,7 @@
 #include "dylib_std.h"
 
 static char sccsid[] UNUSED = "@(#)io.c	3.14	11/11/04" ;
-static char svnid[] UNUSED = "$Id: dylib_io.c 238 2008-06-03 06:14:45Z lou $" ;
+static char svnid[] UNUSED = "$Id: dylib_io.c 407 2010-12-31 20:48:48Z lou $" ;
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -42,6 +42,11 @@ static char svnid[] UNUSED = "$Id: dylib_io.c 238 2008-06-03 06:14:45Z lou $" ;
   that's designed to be called from Fortran. Unless you're the proud
   possessor of some ancient LP software, you likely don't want to know about
   xmp.h.
+
+  WARNING!
+
+  The Fortran hooks haven't been tested since the last millenium. It's highly
+  unlikely that they still work.
 */
 
 #ifdef _DYLIB_FORTRAN
@@ -358,6 +363,7 @@ bool dyio_ioinit (void)
   filblk->fname = "stderr" ;
   setflg(filblk->modes,io_active|io_free|io_write) ;
   filblk->refcnt = 1 ;
+
 /*
   Check for an error log file, and make a filblks entry for it, if necessary.
 */
@@ -373,7 +379,7 @@ bool dyio_ioinit (void)
     { filblk->dname = NULL ;
       fname = errlogpath ; }
     else
-    { len = fname-errlogpath ;
+    { len = (int) (fname-errlogpath) ;
       tmp = (char *) MALLOC(len+1) ;
       (void) strncpy(tmp,errlogpath,len) ;
       tmp[len] = '\0' ;
@@ -401,6 +407,10 @@ void dyio_ioterm (void)
 
 { int id ;
 
+# if MALLOC_DEBUG == 2
+  char *rtnnme = "dyio_ioterm" ;
+# endif
+
 /*
   Data structures allocated by dyio_ioinit to track open files.
 */
@@ -617,7 +627,7 @@ ioid dyio_pathtoid (const char *path, const char *mode)
   { dlen = 0 ;
     fname = path ; }
   else
-  { dlen = fname-path ;
+  { dlen = (int) (fname-path) ;
     fname++ ; }
 
   for (ndx = 1 ; ndx <= maxfiles ; ndx++)
@@ -826,12 +836,12 @@ ioid dyio_openfile (const char *path, const char *mode)
   { filblk->dname = NULL ;
     fname = path ; }
   else
-  { fname++ ;
-    len = fname-path ;
+  { len = (int) (fname-path) ;
     tmp = (char *) MALLOC(len+1) ;
     (void) strncpy(tmp,path,len) ;
     tmp[len] = '\0' ;
-    filblk->dname = tmp ; }
+    filblk->dname = tmp ;
+    fname++ ; }
   tmp = (char *) MALLOC(strlen(fname)+1) ;
   (void) strcpy(tmp,fname) ;
   filblk->fname = tmp ;
@@ -1184,7 +1194,7 @@ bool dyio_scan (ioid id, const char pattern[], bool rwnd, bool wrap)
   if (pattern == NULL)
   { errmsg(2,rtnnme,"pattern") ;
     return (FALSE) ; }
-  patlen = strlen(pattern) ;
+  patlen = (int) strlen(pattern) ;
   if (patlen > MAXPATLEN)
   { errmsg(25,rtnnme,pattern,MAXPATLEN) ;
     patlen = MAXPATLEN ; }
@@ -1200,10 +1210,10 @@ bool dyio_scan (ioid id, const char pattern[], bool rwnd, bool wrap)
   state->nxtchr = *patptr ;
   state->fail = states ;
   for (statendx = 2 ; statendx < patlen ; statendx++)
-  { patndx = state->fail-states ;
+  { patndx = (int) (state->fail-states) ;
     state++ ;
     while (*patptr != pattern[patndx] && patndx > 0)
-      patndx = states[patndx].fail-states ;
+      patndx = (int) (states[patndx].fail-states) ;
     if (*patptr != pattern[patndx] && patndx == 0)
       state->fail = states ;
     else
@@ -1692,7 +1702,6 @@ void dyio_outfmt (ioid id, bool echo, const char *pattern, ... )
 /*
   Print to stream id, assuming it's active and writeable.
 */
-  va_start(parms,pattern) ;
 
   if (id != IOID_NOSTRM)
   { filblk = &filblks[id] ;
@@ -1702,15 +1711,18 @@ void dyio_outfmt (ioid id, bool echo, const char *pattern, ... )
     if (flgon(filblk->modes,io_write) == FALSE)
     { errmsg(17,rtnnme,dyio_idtopath(id)) ; }
     else
-    { (void) vfprintf(filblk->stream,pattern,parms) ; } }
+    { va_start(parms,pattern) ;
+      (void) vfprintf(filblk->stream,pattern,parms) ;
+      va_end(parms) ;
+      } }
 /*
   Print to stdout if echo is TRUE and the stream id is not stdout.
   stdout is assumed active and writeable.
 */
   if (echo == TRUE && id != dyio_pathtoid("stdout",NULL)) 
+  { va_start(parms,pattern) ;
     (void) vfprintf(stdout,pattern,parms) ;
-
-  va_end(parms) ;
+    va_end(parms) ; }
 
   return ; }
 
@@ -1840,7 +1852,7 @@ int dyio_outfxd (char *buffer, int fldsze, char lcr, const char *pattern, ... )
   (void) vsprintf (ourbuf,pattern,parms) ;
   va_end(parms) ;
 
-  tlen = strlen(ourbuf) ;
+  tlen = (int) strlen(ourbuf) ;
   switch (lcr)
   { case 'l':
     { if (fldsze > tlen)
@@ -1878,14 +1890,23 @@ int dyio_outfxd (char *buffer, int fldsze, char lcr, const char *pattern, ... )
 
 #ifdef _DYLIB_FORTRAN
 
+/*
+  WARNING!
+
+  The Fortran hooks haven't been tested since the last millenium. It's highly
+  unlikely that they still work. In particular, it seems likely that each call
+  to vfprintf using the constructed varargs block should be bracked with
+  va_start / va_end.
+*/
+
 void dyio_outfmt_ (integer *ftnid, logical *ftnecho, char *pattern, ... )
 
 /*
   This routine provides a Fortran client with an interface to the vfprintf
   routine of ANSI C and the logging facilities of this i/o library. It deals
   with translating the argument types supplied by Fortran-to-C interface
-  conventions into the arguments required by vprintf. The method is to
-  construct a new varargs block, which is handed over to vprintf. To do
+  conventions into the arguments required by vfprintf. The method is to
+  construct a new varargs block, which is handed over to vfprintf. To do
   this, we have to make the fragile assumption that a varargs block is
   constructed in a straightforward manner --- as data items written into
   a contiguous block of storage which we can allocate. There are more
