@@ -8,7 +8,7 @@
         Burnaby, B.C., V5A 1S6, Canada
         lou@cs.sfu.ca
 
-  This code is licensed under the terms of the Common Public License (CPL).
+  This code is licensed under the terms of the Eclipse Public License (EPL).
 */
 
 /*
@@ -30,6 +30,8 @@
 
 #include "dylp.h"
 
+#include <math.h>
+
 /*
   Macro cleverness to specify a default error message file. Depends on ANSI
   C merge of consecutive string constants. DYLP_ERRMSGDIR should have the
@@ -40,7 +42,7 @@
 #ifdef DYLP_ERRMSGDIR
 # define DYLP_ERRMSGPATH DYLP_ERRMSGDIR "dy_errmsgs.txt"
 #else
-# define DYLP_ERRMSGPATH "dy_errmsgs.txt"
+# define DYLP_ERRMSGPATH "../src/Dylp/dy_errmsgs.txt"
 #endif
 
 /*
@@ -48,22 +50,14 @@
 
   ttyout		i/o id for output to the user's terminal
   ttyin			i/o id for input from the user's terminal
-  dy_cmdchn		i/o id for input from the command file
-  dy_logchn		i/o id for the execution log file
 
-  dy_cmdecho		controls echoing of command input to stdout
+  dy_logchn		i/o id for the execution log file
   dy_gtxecho		controls echoing of generated text to stdout
 */
 
-ioid dy_cmdchn,dy_logchn ;
-bool dy_cmdecho, dy_gtxecho ;
+ioid dy_logchn ;
+bool dy_gtxecho ;
 
-/*
-  Define these as globals for the benefit of cmdint.c::process_cmds.
-*/
-
-lpopts_struct* main_lpopts ;
-lptols_struct* main_lptols ;
 
 
 
@@ -93,7 +87,9 @@ static lpret_enum do_lp (lpprob_struct *lp,
 
   consys_struct *sys ;
 
-  /* const char *rtnnme = "do_lp" ; */
+# if MALLOC_DEBUG == 2
+  const char *rtnnme = "do_lp" ;
+# endif
 
   lpret = lpINV ;
   sys = lp->consys ;
@@ -137,12 +133,6 @@ int main (int argc, char **argv)
   const char *errmsgpath = DYLP_ERRMSGPATH ;
   char *errlogpath = NULL ;
 
-/*
-  These need to be globals to keep cmdint.c::process_cmds happy.
-
-  lpopts_struct *main_lpopts ;
-  lptols_struct *main_lptols ;
-*/
   consys_struct *main_sys ;
   lpprob_struct *main_lp ;
   lpret_enum lpretval ;
@@ -150,6 +140,9 @@ int main (int argc, char **argv)
   double z ;
   int errcnt,cnt ;
 
+  lpopts_struct* main_lpopts ;
+  lptols_struct* main_lptols ;
+
 /*
   Set this to TRUE if you want to see the solutions for the test lp problems.
 */
@@ -228,9 +221,7 @@ int main (int argc, char **argv)
   { errmsg(1,rtnnme,__LINE__) ;
     exit(4) ; }
   (void) dyio_setmode(ttyin,'l') ;
-  dy_cmdchn = ttyin ;
   dy_logchn = IOID_NOSTRM ;
-  dy_cmdecho = TRUE ;
   dy_gtxecho = TRUE ;
 /*
   Announce we're running.
